# weq8

A parametric equaliser for Web Audio.

Sculpt the spectrum of your Web Audio graph using a filter bank of up to eight filters, with an intuitive UI inspired by Ableton Live's [EQ Eight](https://www.ableton.com/en/manual/live-audio-effect-reference/#24-15-eq-eight).

- Built on top of standard [BiquadFilterNode](https://developer.mozilla.org/en-US/docs/Web/API/BiquadFilterNode)s.
- Includes lowpass, highpass, lowshelf, highshelf, peaking, and notch filters, all with -12dB or -24dB roll-off.
- Controlled with a Web Component UI, or headlessly with a TypeScript/JavaScript API.

## Usage

### Install

As an NPM package:

```bash
yarn add weq8
# or
npm install weq8
```

Or include as a `<script>` using Skypack:

### Setup and Connect The Runtime

The audio processing of the equaliser all happens in an instance of the `WEQ8Runtime` class. You'll need to import it, initialise it using your [AudioContext](https://developer.mozilla.org/en-US/docs/Web/API/AudioContext), and connect it to the signal path of the audio source you wish to equalise:

```ts
import { WEQ8Runtime } from "weq8";

let weq8 = new WEQ8Runtime(yourAudioCtx);
yourAudioSourceNode.connect(weq8.input);
weq8.connect(yourAudioDestinationNode);
```

### Plug in The UI

The user interface for the equaliser is provided by a [Web Component](https://developer.mozilla.org/en-US/docs/Web/Web_Components) called `<weq8-ui />`. First import the UI package so that this web component gets registered:

```ts
import "weq8/ui";
```

Then in your HTML, where you want the equaliser UI to appear, add the element:

```html
<weq8-ui />
```

And finally, connect the `WEQ8Runtime` you initialised into this UI by setting it as a property:

```ts
document.querySelector("weq8-ui").runtime = weq8;
```

You should see the fully functional UI appear on your page.

## Programmatic Control

## Persisting Filter State
